from django.apps import AppConfig


class MarkdownConfig(AppConfig):
    name = 'django_bootstrap_markdown'
    verbose_name = 'Django Bootstrap Markdown'
